/*
 * query.h
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of sqlite3cc (hereafter referred to as "this program").
 * See http://www.waxworlds.org/edam/software/sqlite3cc for more information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SQLITE3CC_QUERY_H_
#define SQLITE3CC_QUERY_H_


#include <sqlite3cc/basic_statement.h>


namespace sqlite
{


class row;


class query
	:
	public basic_statement
{
//______________________________________________________________________________
//                                                                 instantiation
public:

	/**
	 * Constructor that provides a database upon which to act and the SQL
	 * query to execute.
	 * @param database a reference to a database
	 * @param sql an SQL statement in UTF-8
	 */
	explicit query(
		database &database,
		const std::string &sql );

	/**
	 * Constructor that provides a database upon which to act.
	 * @param database a reference to a database
	 * @param sql an SQL statement in UTF-8
	 */
	explicit query(
		database &database );

//______________________________________________________________________________
//                                                              public interface
public:

	/**
	 * Prepare an SQL statement.
	 * @param sql an SQL statement in UTF-8
	 * @returns an sqlite error code
	 * @see sqlite3_prepare_v2()
	 */
	virtual int prepare(
		const std::string &sql );

	/**
	 * Peform a step() and return row object that can be used to retrieve the
	 * results.
	 * @return a row object
	 */
	row step();

	/**
	 * Get the number of columns in the result of
	 */
	unsigned int column_count();

};


} // namespace sqlite


#endif /* SQLITE3CC_QUERY_H_ */
