/*
 * command.cc
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of sqlite3cc (hereafter referred to as "this program").
 * See http://www.waxworlds.org/edam/software/sqlite3cc for more information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <sqlite3cc/command.h>
#include <sqlite3cc/database.h>
#include <boost/thread/locks.hpp>
#include <cassert>


boost::recursive_mutex sqlite::command::_command_mutex;


sqlite::command::command(
	database &database,
	const std::string &sql )
	:
	basic_statement( database, sql ),
	_changes( 0 ),
	_total_changes( 0 ),
	_last_insert_rowid( 0 )
{
	assert( sqlite3_column_count( _handle ) == 0 );
}


sqlite::command::command(
	database &database )
	:
	basic_statement( database ),
	_changes( 0 ),
	_total_changes( 0 ),
	_last_insert_rowid( 0 )
{
}


int sqlite::command::prepare(
	const std::string &sql )
{
	int error_code = basic_statement::prepare( sql );
	assert( error_code != SQLITE_OK || sqlite3_column_count( _handle ) == 0 );
	return error_code;
}


int sqlite::command::step()
{
	boost::lock_guard< boost::recursive_mutex > lock( _command_mutex );
	int error_code = basic_statement::step();
	if( error_code == SQLITE_OK ) {
		_changes = sqlite3_changes( _database._handle );
		_total_changes = sqlite3_total_changes( _database._handle );
		_last_insert_rowid = sqlite3_last_insert_rowid( _database._handle );
	}
	return error_code;
}
