/*
 * query.cc
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of sqlite3cc (hereafter referred to as "this program").
 * See http://www.waxworlds.org/edam/software/sqlite3cc for more information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <sqlite3cc/query.h>
#include <sqlite3cc/row.h>
#include <assert.h>


sqlite::query::query(
	database &database,
	const std::string &sql )
	:
	basic_statement( database, sql )
{
	assert( sqlite3_column_count( _handle ) > 0 );
}


sqlite::query::query(
	database &database )
	:
	basic_statement( database )
{
}


int sqlite::query::prepare(
	const std::string &sql )
{
	int error_code = basic_statement::prepare( sql );
	assert( error_code != SQLITE_OK || sqlite3_column_count( _handle ) > 0 );
	return error_code;
}


sqlite::row sqlite::query::step()
{
	int error_code = basic_statement::step();
	if( error_code == SQLITE_ROW )
		return row( *this );
	if( error_code == SQLITE_DONE )
		return row( *this, false );
	throw sqlite_error( error_code );
}


unsigned int sqlite::query::column_count()
{
	return sqlite3_column_count( _handle );
}
