/*
 * row.cc
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of sqlite3cc (hereafter referred to as "this program").
 * See http://www.waxworlds.org/edam/software/sqlite3cc for more information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <sqlite3cc/row.h>
#include <sqlite3cc/query.h>
#include <sqlite3cc/manipulator.h>
#include <cassert>


sqlite::row::row(
	query &query,
	bool valid )
	:
	_query( query ),
	_column_index( 0 ),
	_valid( valid )
{
}


int sqlite::row::column_type(
	unsigned int index )
{
	assert( index <= _query.column_count() );
	return sqlite3_column_type( _query._handle, index );
}


unsigned int sqlite::row::column_bytes(
	unsigned int index )
{
	return sqlite3_column_bytes( _query._handle, index );
}


sqlite::row &sqlite::row::operator >>(
	_set_index_t t )
{
	_column_index = t._index;
	return *this;
}


template< >
sqlite::row &sqlite::row::operator >> < sqlite::_null_t >(
	_null_t & )
{
	assert( _column_index < _query.column_count() );
	_column_index++;
	return *this;
}
